//
// make.h
//
// Build Your Own Electronic Game Kit PCB
//
// This file contains code for the Microchip PIC16LF628A/648A for CCS PCM
//
// Created by Joe Grand, Grand Idea Studio, Inc., February 20, 2006
// http://www.grandideastudio.com/portfolio/build-your-own-electronic-game-kit/
//
// Distributed under a Creative Commons Attribution-Share Alike 3.0 Unported license:
// http://creativecommons.org/licenses/by-sa/3.0/
//

#ifndef __INC_MAKE_H__
#define __INC_MAKE_H__

#include <16F628A.h>
#use delay(clock=4000000)

// Configuration Bits:
// Oscillator = INT RC - I/O on RA6/RA7
// Watchdog Timer (WDT) = DISABLED
// Power Up Timer (PWRT) = ENABLED
// Brown-Out Detect (BOR) = DISABLED
// Master Clear = ENABLED
// Low Voltage Program = DISABLED
// Data EE Read Protect = DISABLED
// Code Protect = DISABLED
#fuses INTRC_IO, NOWDT, PUT, NOBROWNOUT, MCLR, NOLVP, NOPROTECT, NOCPD

// port definitions
#define LED_RED         PIN_A2
#define LED_GREEN       PIN_A3
#define LED_BLUE        PIN_A1
#define LED_YELLOW      PIN_A0

#define SW_RED          PIN_B5
#define SW_GREEN        PIN_B4
#define SW_BLUE         PIN_B6
#define SW_YELLOW       PIN_B7

#define SW_NO_BUTTON    0xF0
#define SW_RED_MASK     0x02
#define SW_GREEN_MASK   0x01
#define SW_BLUE_MASK    0x04
#define SW_YELLOW_MASK  0x08

#define CLK_OUT         PIN_B3
#define TONE_PIN        PIN_A6


// constants
#define EEPROM_SIZE    			128			// size of PIC's internal EEPROM used for gameplay storage

#define INTS_PER_SECOND         15          // (4000000/(4*256*256))

#define TIMEOUT_DELAY_EASY      6           // delay (in s) to wait for a player to make a move choice
#define TIMEOUT_DELAY_HARD      3
#define BETWEEN_MOVE_ON_DELAY   300         // delay (in ms) to show the current moves
#define BETWEEN_MOVE_OFF_DELAY_EASY  500    // delay (in ms) to pause in between showing the moves
#define BETWEEN_MOVE_OFF_DELAY_HARD  150

#define RED_MOVE        0x00    // move values stored in internal EEPROM
#define GREEN_MOVE      0x01
#define BLUE_MOVE       0x02
#define YELLOW_MOVE     0x03

#define SILENT_MODE     0x01    // game configuration flags (set on power-up)
#define BLIND_MODE      0x02
#define EXPERT_MODE     0x04
#define REVERSE_MODE    0x08


// FUNCTION PROTOTYPES 
// (main.c)
void simon_config(void);
BOOLEAN simon_game(void);
void simon_play_moves(void);
BOOLEAN simon_read_moves(void);
void simon_failed_input(void);
void hardware_init (void);

// (tones.c)
void generate_tone(long frequency, long duration);

#endif
